@@ -4,7 +4,7 @@
  *
  * PHP version 5
  *
- * Copyright 2009-2011 Horde LLC (http://www.horde.org/)
+ * Copyright 2009-2013 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -17,10 +17,5 @@
  * @link       http://pear.horde.org/index.php?package=Token
  */
 
-require_once 'Horde/Test/Autoload.php';
-
-/* Catch strict standards */
-error_reporting(E_ALL | E_STRICT);
-
 /** Load basic test case definitions */
-require_once dirname(__FILE__) . '/BackendTestCase.php';
+require_once __DIR__ . '/BackendTestCase.php';
